package com.baijiayun.flutter.bjy_liveui_flutter

import android.app.Activity
import android.app.Application
import androidx.annotation.NonNull
import com.baijiayun.livecore.LiveSDK
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** BJYLiveUIFlutterPlugin */
class BJYLiveUIFlutterPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel

    private var activity: Activity? = null

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "bjy_liveui_flutter")
        channel.setMethodCallHandler(this)
        LiveSDK.init(flutterPluginBinding.applicationContext as Application?)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        activity?.run {
            when (call.method) {
                "init" -> {
                    val domain = call.argument<String>("domain") ?: ""
                    LiveSDK.customEnvironmentPrefix = domain
                }
                "startLiveByCodeWithLayoutTemplateAndCodeAndUserName" -> {
                    val code = call.argument<String>("code") ?: ""
                    val userName = call.argument<String>("userName") ?: ""
                    when (call.argument<String>("template")) {
                        Template.Triple.getName() -> {
                            startLiveTripleTemplateWithCode(this, code, userName)
                        }

                        Template.Enterprise.getName() -> {
                            startLiveEETemplateWithCode(this, code, userName)
                        }

                        Template.Sell.getName() -> {
                            startLiveSellTemplateWithCode(this, code, userName)
                        }

                        Template.Professional.getName() -> {
                            startProfessionalLiveTemplateWithCode(this, code, userName)
                        }
                    }
                }
                "startLiveBySignWithLayoutTemplateAndRoomIDAndSignAndUserInfo" -> {
                    val roomID = call.argument<String>("roomID") ?: ""
                    val sign = call.argument<String>("sign") ?: ""
                    val userInfoMap = call.argument<HashMap<String, Any>>("userInfo") ?: HashMap()
                    when (call.argument<String>("template")) {
                        Template.Triple.getName() -> {
                            startLiveTripleTemplateWithSign(this, roomID, sign, userInfoMap)
                        }

                        Template.Enterprise.getName() -> {
                            startLiveEETemplateWithSign(this, roomID, sign, userInfoMap)
                        }

                        Template.Sell.getName() -> {
                            startLiveSellTemplateWithSign(this, roomID, sign, userInfoMap)
                        }

                        Template.Professional.getName() -> {
                            startProfessionalLiveTemplateWithSign(this, roomID, sign, userInfoMap)
                        }
                    }
                }

                else -> {
                    result.notImplemented()
                }
            }
        } ?: result.notImplemented()
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
        onDetachedFromActivity()
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        onAttachedToActivity(binding)
    }

    override fun onDetachedFromActivity() {
        this.activity = null
    }
}
