import Flutter
import UIKit
import BJLiveUIBase

public class SwiftBJYLiveUIFlutterPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "bjy_liveui_flutter", binaryMessenger: registrar.messenger())
    let instance = SwiftBJYLiveUIFlutterPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
      switch (call.method) {
          case "init":
              let args = call.arguments as? NSDictionary
              guard let args = args else { return }
              
              BJLRoom.setPrivateDomainPrefix(valByKey(args, key: "domain"))

          case "startLiveByCodeWithLayoutTemplateAndCodeAndUserName":
              let args = call.arguments as? NSDictionary
              guard let args = args else { return }
             
              startLiveWithTemplate(
                roomVCTypeWithString(valByKey(args, key: "template")),
                code: valByKey(args, key: "code"),
                userName: valByKey(args, key: "userName")
              )
              
          case "startLiveBySignWithLayoutTemplateAndRoomIDAndSignAndUserInfo":
              let args = call.arguments as? NSDictionary
              guard let args = args else { return }
              
              startLiveWithTemplate(
                roomVCTypeWithString(valByKey(args, key: "template")),
                sign: valByKey(args, key: "sign"),
                roomID: valByKey(args, key: "roomID"),
                userInfo: args["userInfo"] as? NSDictionary
              )
              
          default:
              print("undefine action")
      }
    
      func valByKey(_ dic: NSDictionary, key: String) -> String {
          let val = (dic[key] ?? "") as? String ?? ""
          return val
      }
  }
}

extension SwiftBJYLiveUIFlutterPlugin {
    func roomVCTypeWithString(_ typeString: String) -> BJLRoomVCType {
        var result = BJLRoomVCType.bigClass
        switch(typeString) {
            case "triple":
                result = .bigClass
            case "enterprise":
                result = .enterpriseEdition
            case "sell":
                result = .sell
            case "professional":
                result = .smallClass
            default:
                result = .bigClass
        }
        return result
    }
    
    func startLiveWithTemplate(_ template: BJLRoomVCType, code: String, userName: String) {
        let roomCode = BJLRoomCode()
        roomCode.code = code
        roomCode.userName = userName
        roomCode.userAvatar = ""
        
        let vc = BJLRoomViewController.instance(withRoomType: template, roomCode: roomCode) as? UIViewController
        guard let vc = vc else { return }
        
        bjy_findCurrentShowingViewController()?.bjl_presentFullScreenViewController(vc, animated: true)
    }
    
    func startLiveWithTemplate(_ template: BJLRoomVCType, sign: String, roomID: String, userInfo: NSDictionary?) {
        var user = BJLUser()
        if let userInfo = userInfo {
            user = BJLUser(
                number: userInfo.bjl_string(forKey: "number", defaultValue: "") ?? "",
                name: userInfo.bjl_string(forKey: "name", defaultValue: "") ?? "",
                groupID: userInfo.bjl_integer(forKey: "groupID"),
                avatar: userInfo.bjl_string(forKey: "avatar", defaultValue: "") ?? "",
                role: BJLUserRole(rawValue: userInfo.bjl_integer(forKey: "role")) ?? .student
            )
        }
        let roomIDObj = BJLRoomID()
        roomIDObj.roomID = roomID
        roomIDObj.apiSign = sign
        roomIDObj.user = user
        
        let vc = BJLRoomViewController.instance(withRoomType: template, roomID: roomIDObj)  as? UIViewController
        guard let vc = vc else { return }
        
        bjy_findCurrentShowingViewController()?.bjl_presentFullScreenViewController(vc, animated: true)
    }

    func bjy_findCurrentShowingViewController() -> UIViewController? {
        let vc = UIApplication.shared.keyWindow?.rootViewController
        let currentShowingVC = bjy_findCurrentShowingViewControllerFrom(vc)
        currentShowingVC?.modalPresentationStyle = .fullScreen
        return currentShowingVC
    }
    
    func bjy_findCurrentShowingViewControllerFrom(_ vc: UIViewController?) -> UIViewController? {
        guard let vc = vc else { return nil }
        
        var currentShowingVC: UIViewController?
        
        if let vcp = vc.presentedViewController {
            // 当前视图是被presented出来的
            currentShowingVC = bjy_findCurrentShowingViewControllerFrom(vcp);
        }
        else if vc.isKind(of: UITabBarController.self) {
            let tabvc = vc as? UITabBarController
            currentShowingVC = bjy_findCurrentShowingViewControllerFrom(tabvc?.selectedViewController)
        }
        else if vc.isKind(of: UINavigationController.self) {
            let navvc = vc as? UINavigationController
            currentShowingVC = bjy_findCurrentShowingViewControllerFrom(navvc?.visibleViewController)
        }
        else {
            currentShowingVC = vc;
        }
        
        return currentShowingVC;
    }
}
